@@ -1,22 +1,30 @@
 import importlib
 from contextlib import suppress
+from typing import Optional, Dict, Any
+from typing import TYPE_CHECKING
 
 from pyhon import helper
 from pyhon.commands import HonCommand
-from pyhon.parameter import HonParameterFixed
+from pyhon.parameter.fixed import HonParameterFixed
+
+if TYPE_CHECKING:
+    from pyhon import HonAPI
 
 
 class HonAppliance:
-    def __init__(self, api, info):
+    def __init__(
+        self, api: Optional["HonAPI"], info: Dict[str, Any], zone: int = 0
+    ) -> None:
         if attributes := info.get("attributes"):
             info["attributes"] = {v["parName"]: v["parValue"] for v in attributes}
-        self._info = info
-        self._api = api
-        self._appliance_model = {}
+        self._info: Dict = info
+        self._api: Optional[HonAPI] = api
+        self._appliance_model: Dict = {}
 
-        self._commands = {}
-        self._statistics = {}
-        self._attributes = {}
+        self._commands: Dict = {}
+        self._statistics: Dict = {}
+        self._attributes: Dict = {}
+        self._zone: int = zone
 
         try:
             self._extra = importlib.import_module(
@@ -26,20 +34,21 @@ class HonAppliance:
             self._extra = None
 
     def __getitem__(self, item):
+        if self._zone:
+            item += f"Z{self._zone}"
         if "." in item:
             result = self.data
             for key in item.split("."):
-                if all([k in "0123456789" for k in key]) and type(result) is list:
+                if all(k in "0123456789" for k in key) and isinstance(result, list):
                     result = result[int(key)]
                 else:
                     result = result[key]
             return result
-        else:
-            if item in self.data:
-                return self.data[item]
-            if item in self.attributes["parameters"]:
-                return self.attributes["parameters"].get(item)
-            return self.info[item]
+        if item in self.data:
+            return self.data[item]
+        if item in self.attributes["parameters"]:
+            return self.attributes["parameters"].get(item)
+        return self.info[item]
 
     def get(self, item, default=None):
         try:
@@ -47,25 +56,35 @@ class HonAppliance:
         except (KeyError, IndexError):
             return default
 
-    @property
-    def appliance_model_id(self):
-        return self._info.get("applianceModelId")
+    def _check_name_zone(self, name: str, frontend: bool = True) -> str:
+        middle = " Z" if frontend else "_z"
+        if (attribute := self._info.get(name, "")) and self._zone:
+            return f"{attribute}{middle}{self._zone}"
+        return attribute
 
     @property
-    def appliance_type(self):
-        return self._info.get("applianceTypeName")
+    def appliance_model_id(self) -> str:
+        return self._info.get("applianceModelId", "")
 
     @property
-    def mac_address(self):
-        return self._info.get("macAddress")
+    def appliance_type(self) -> str:
+        return self._info.get("applianceTypeName", "")
 
     @property
-    def model_name(self):
-        return self._info.get("modelName")
+    def mac_address(self) -> str:
+        return self.info.get("macAddress", "")
 
     @property
-    def nick_name(self):
-        return self._info.get("nickName")
+    def unique_id(self) -> str:
+        return self._check_name_zone("macAddress", frontend=False)
+
+    @property
+    def model_name(self) -> str:
+        return self._check_name_zone("modelName")
+
+    @property
+    def nick_name(self) -> str:
+        return self._check_name_zone("nickName")
 
     @property
     def commands_options(self):
@@ -87,6 +106,10 @@ class HonAppliance:
     def info(self):
         return self._info
 
+    @property
+    def zone(self) -> int:
+        return self._zone
+
     async def _recover_last_command_states(self, commands):
         command_history = await self._api.command_history(self)
         for name, command in commands.items():
@@ -101,8 +124,8 @@ class HonAppliance:
             if last is None:
                 continue
             parameters = command_history[last].get("command", {}).get("parameters", {})
-            if command._multi and parameters.get("program"):
-                command.set_program(parameters.pop("program").split(".")[-1].lower())
+            if command.programs and parameters.get("program"):
+                command.program = parameters.pop("program").split(".")[-1].lower()
                 command = self.commands[name]
             for key, data in command.settings.items():
                 if (
@@ -126,7 +149,12 @@ class HonAppliance:
                 for program, attr2 in attr.items():
                     program = program.split(".")[-1].lower()
                     cmd = HonCommand(
-                        command, attr2, self._api, self, multi=multi, program=program
+                        command,
+                        attr2,
+                        self._api,
+                        self,
+                        programs=multi,
+                        program_name=program,
                     )
                     multi[program] = cmd
                     commands[command] = cmd
@@ -147,7 +175,9 @@ class HonAppliance:
     def parameters(self):
         result = {}
         for name, command in self._commands.items():
-            for key, parameter in command.parameters.items():
+            for key, parameter in (
+                command.parameters | command.ancillary_parameters
+            ).items():
                 result.setdefault(name, {})[key] = parameter.value
         return result
 
@@ -177,7 +207,7 @@ class HonAppliance:
     @property
     def diagnose(self):
         data = self.data.copy()
-        for sensible in ["PK", "SK", "serialNumber", "code"]:
+        for sensible in ["PK", "SK", "serialNumber", "code", "coords"]:
             data["appliance"].pop(sensible, None)
         result = helper.pretty_print({"data": self.data}, whitespace="\u200B \u200B ")
         result += helper.pretty_print(
